@@ -195,6 +195,11 @@ def onConnected(interface):
             print(f"Setting device owner to {args.set_owner}")
             interface.getNode(args.dest).setOwner(args.set_owner)
 
+        if args.set_owner_short:
+            closeNow = True
+            print(f"Setting device owner short to {args.set_owner_short}")
+            interface.getNode(args.dest).setOwner(long_name=None, short_name=args.set_owner_short)
+
         if args.pos_fields:
             # If --pos-fields invoked with args, set position fields
             closeNow = True
@@ -252,6 +257,10 @@ def onConnected(interface):
             closeNow = True
             interface.getNode(args.dest).reboot()
 
+        if args.shutdown:
+            closeNow = True
+            interface.getNode(args.dest).shutdown()
+
         if args.sendtext:
             closeNow = True
             channelIndex = 0
@@ -292,12 +301,11 @@ def onConnected(interface):
                     print(f"Reading GPIO mask 0x{bitmask:x} from {args.dest}")
                     interface.mask = bitmask
                     rhc.readGPIOs(args.dest, bitmask, None)
-                    if not interface.noProto:
-                        # wait up to X seconds for a response
-                        for _ in range(10):
-                            time.sleep(1)
-                            if interface.gotResponse:
-                                break
+                    # wait up to X seconds for a response
+                    for _ in range(10):
+                        time.sleep(1)
+                        if interface.gotResponse:
+                            break
                     logging.debug(f'end of gpio_rd')
 
                 if args.gpio_watch:
@@ -328,6 +336,14 @@ def onConnected(interface):
                     print(f"Setting device owner to {configuration['owner']}")
                     interface.getNode(args.dest).setOwner(configuration['owner'])
 
+                if 'owner_short' in configuration:
+                    print(f"Setting device owner short to {configuration['owner_short']}")
+                    interface.getNode(args.dest).setOwner(long_name=None, short_name=configuration['owner_short'])
+
+                if 'ownerShort' in configuration:
+                    print(f"Setting device owner short to {configuration['ownerShort']}")
+                    interface.getNode(args.dest).setOwner(long_name=None, short_name=configuration['ownerShort'])
+
                 if 'channel_url' in configuration:
                     print("Setting channel url to", configuration['channel_url'])
                     interface.getNode(args.dest).setURL(configuration['channel_url'])
@@ -565,6 +581,7 @@ def subscribe():
 def export_config(interface):
     """used in--export-config"""
     owner = interface.getLongName()
+    owner_short = interface.getShortName()
     channel_url = interface.localNode.getURL()
     myinfo = interface.getMyNodeInfo()
     pos = myinfo.get('position')
@@ -579,6 +596,8 @@ def export_config(interface):
     config = "# start of Meshtastic configure yaml\n"
     if owner:
         config += f"owner: {owner}\n\n"
+    if owner_short:
+        config += f"owner_short: {owner_short}\n\n"
     if channel_url:
         if Globals.getInstance().get_camel_case():
             config += f"channelUrl: {channel_url}\n\n"
@@ -761,7 +780,12 @@ def initParser():
         "--ch-disable", help="Disable the specified channel", action="store_true", dest="ch_disable", default=False)
 
     parser.add_argument(
-        "--ch-set", help="Set a channel parameter", nargs=2, action='append')
+        "--ch-set", help=("Set a channel parameter. To see channel settings available:'--ch-set all all --ch-index 0'. "
+                          "Can set the 'psk' using this command. To disable encryption on primary channel:'--ch-set psk none --ch-index 0'. "
+                          "To set encryption with a new random key on second channel:'--ch-set psk random --ch-index 1'. "
+                          "To set encryption back to the default:'--ch-set default --ch-index 0'. To set encryption with your "
+                          "own key: '--ch-set psk 0x1a1a1a1a2b2b2b2b1a1a1a1a2b2b2b2b1a1a1a1a2b2b2b2b1a1a1a1a2b2b2b2b --ch-index 0'."),
+                          nargs=2, action='append')
 
     parser.add_argument(
         "--ch-longslow", help="Change to the long-range and slow channel", action='store_true')
@@ -781,10 +805,12 @@ def initParser():
     parser.add_argument(
         "--ch-shortfast", help="Change to the short-range and fast channel", action='store_true')
 
-
     parser.add_argument(
         "--set-owner", help="Set device owner name", action="store")
 
+    parser.add_argument(
+        "--set-owner-short", help="Set device owner short name", action="store")
+
     parser.add_argument(
         "--set-team", help="Set team affiliation (an invalid team will list valid values)", action="store")
 
@@ -803,6 +829,9 @@ def initParser():
     parser.add_argument(
         "--reboot", help="Tell the destination node to reboot", action="store_true")
 
+    parser.add_argument(
+        "--shutdown", help="Tell the destination node to shutdown", action="store_true")
+
     parser.add_argument(
         "--reply", help="Reply to received messages",
         action="store_true")
